==> r2c_cli-0.0.7-py3-none-any.whl: r2c/cli/create_template.py <==
import json
import os
import shutil
import sys
from pathlib import Path
from typing import Optional

import click

DOCKER_FILE = """FROM ubuntu:17.10

RUN groupadd -r analysis && useradd --no-log-init --system --gid analysis analysis
USER analysis

COPY --chown=analysis:analysis src /analyzer
WORKDIR /
CMD ["/analyzer/analyze.sh"]"""

UNITTEST_SH = """#!/bin/bash

echo "⚠️ Empty unittest!"
"""

ANALYZE_SH = """#!/bin/bash

set -e
CODE_DIR="/analysis/inputs/source-code"

echo "{\\"results\\": []}" | tee /analysis/output/output.json"""


def create_file(path, content):
    with open(path, "w", newline="\n", encoding="utf-8") as f:
        f.write(content)
    os.chmod(path, 0o775)


def create_template_analyzer(
    org: Optional[str],
    analyzer_name: str,
    author_name: str,
    author_email: str,
    run_on: str,
    output_type: str,
) -> None:
    analyzer_json_dict = {
        # TODO get from default org
        "analyzer_name": f"{org or 'example_org'}/{analyzer_name}",
        # "author_name": author_name,
        # "author_email": author_email,
        "version": "0.0.1",
        "spec_version": "1.0.0",
        "dependencies": {"public/source-code": "*"},
        "type": run_on,
        "output": output_type,
        "deterministic": True,
    }
    try:
        Path(os.path.join(analyzer_name, "src")).mkdir(parents=True)
        analyzer_json_path = os.path.join(analyzer_name, "analyzer.json")
        with open(analyzer_json_path, "w", newline="\n", encoding="utf-8") as fp:
            json.dump(analyzer_json_dict, fp, indent=4)
        dockerfile_path = os.path.join(analyzer_name, "Dockerfile")
        with open(dockerfile_path, "w", newline="\n", encoding="utf-8") as fp:
            fp.write(DOCKER_FILE)
        create_file(os.path.join(analyzer_name, "src", "analyze.sh"), ANALYZE_SH)
        create_file(os.path.join(analyzer_name, "src", "unittest.sh"), UNITTEST_SH)
    except FileExistsError as e:
        click.echo(f"❌ {analyzer_name} already exists. Please delete and run again")
        sys.exit(1)
    except Exception as e:
        click.echo(
            f"❌ Error creating template. Please contact us at cli@ret2.co with the following information: {e}"
        )
        sys.exit(1)

==> r2c_cli-0.0.10-py3-none-any.whl: r2c/cli/create_template.py <==
import json
import os
import shutil
import sys
from pathlib import Path
from typing import Optional

import click

DOCKER_FILE = """FROM ubuntu:17.10

RUN groupadd -r analysis && useradd --no-log-init --system --gid analysis analysis
USER analysis

COPY --chown=analysis:analysis src /analyzer
WORKDIR /
CMD ["/analyzer/analyze.sh"]"""

UNITTEST_SH = """#!/bin/bash

echo "⚠️ Empty unittest!"
"""

ANALYZE_SH = """#!/bin/bash

set -e
CODE_DIR="/analysis/inputs/public/source-code"

echo "{\\"results\\": []}" | tee /analysis/output/output.json"""


def create_file(path, content):
    with open(path, "w", newline="\n", encoding="utf-8") as f:
        f.write(content)
    os.chmod(path, 0o775)


def create_template_analyzer(
    org: Optional[str],
    analyzer_name: str,
    author_name: str,
    author_email: str,
    run_on: str,
    output_type: str,
) -> None:
    analyzer_json_dict = {
        # TODO get from default org
        "analyzer_name": f"{org or 'example_org'}/{analyzer_name}",
        # "author_name": author_name,
        # "author_email": author_email,
        "version": "0.0.1",
        "spec_version": "1.0.0",
        "dependencies": {"public/source-code": "*"},
        "type": run_on,
        "output": output_type,
        "deterministic": True,
    }
    try:
        Path(os.path.join(analyzer_name, "src")).mkdir(parents=True)
        analyzer_json_path = os.path.join(analyzer_name, "analyzer.json")
        with open(analyzer_json_path, "w", newline="\n", encoding="utf-8") as fp:
            json.dump(analyzer_json_dict, fp, indent=4)
        dockerfile_path = os.path.join(analyzer_name, "Dockerfile")
        with open(dockerfile_path, "w", newline="\n", encoding="utf-8") as fp:
            fp.write(DOCKER_FILE)
        create_file(os.path.join(analyzer_name, "src", "analyze.sh"), ANALYZE_SH)
        create_file(os.path.join(analyzer_name, "src", "unittest.sh"), UNITTEST_SH)
    except FileExistsError as e:
        click.echo(f"❌ {analyzer_name} already exists. Please delete and run again")
        sys.exit(1)
    except Exception as e:
        click.echo(
            f"❌ Error creating template. Please contact us at cli@ret2.co with the following information: {e}"
        )
        sys.exit(1)
